@@ -8,7 +8,7 @@
 #
 package PerlIO::via::Timeout;
 {
-  $PerlIO::via::Timeout::VERSION = '0.28';
+  $PerlIO::via::Timeout::VERSION = '0.29';
 }
 
 # ABSTRACT: a PerlIO layer that adds read & write timeout to a handle
@@ -161,14 +161,14 @@ sub _can_read_write {
 
 sub read_timeout {
     my $prop = __PACKAGE__->_fh2prop($_[0]);
-    @_ > 1 and $prop->{read_timeout} = $_[1], _check_attributes($prop);
+    @_ > 1 and $prop->{read_timeout} = $_[1] || 0, _check_attributes($prop);
     $prop->{read_timeout};
 }
 
 
 sub write_timeout {
     my $prop = __PACKAGE__->_fh2prop($_[0]);
-    @_ > 1 and $prop->{write_timeout} = $_[1], _check_attributes($prop);
+    @_ > 1 and $prop->{write_timeout} = $_[1] || 0, _check_attributes($prop);
     $prop->{write_timeout};
 }
 
@@ -203,7 +203,7 @@ PerlIO::via::Timeout - a PerlIO layer that adds read & write timeout to a handle
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
